@@ -15,5 +15,5 @@ void F77_NAME(simfilter)(int *ymiss,int *timevar, double *yt, double *zt, double
 void F77_NAME(ngfilter)(double *yt, int *ymiss, int *timevar, double *zt, double *tt, double *rtv, double *qt, double *a1, double *p1,double *p1inf, double *u, double *theta,int *dist, int *p,int *n, int *m, int *r, int *rankp, int *nnd,int *nsim,double *epsplus,double *etaplus,double *aplus1,double *c,double *tol,int *info, int *maxiter,double *convtol,int *nd,int *ndl,double *alphahat,double *alphavar,double *thetahat,double *thetavar,double *yhat,double *yvar,int *smootha, int *smooths, int *smoothy);
 void F77_NAME(isamplefilter)(double *yt, int *ymiss, int *timevar, double *zt, double *tt, double *rtv, double *qt, double *a1, double *p1,double *p1inf, double *u, int *dist, int *p, int *n, int *m, int *r, double *theta, int *maxiter,int *rankp,double *convtol, int *nnd,int *nsim, double *epsplus,double *etaplus,double *aplus1,double *c,double *tol,int *info, int *antithetics, double *w,double *sim, int *nd,int *ndl, int *simwhat, int *simdim);
 void F77_NAME(simgaussian)(int *ymiss, int *timevar, double *yt, double *zt, double *ht, double *tt, double *rtv, double *qt, double *a1, double *p1, double *p1inf, int *nnd, int *nsim, double *epsplus, double *etaplus, double *aplus1, int *p, int *n, int *m, int *r, int *info,int *rankp, double *tol, int *nd, int *ndl, double *sim, double *c, int *simwhat, int *simdim, int *antithetics);
-void F77_NAME(simgaussianuncond)(int *ymiss, int *timevar, double *yt, double *zt, double *ht, double *tt, double *rtv, double *qt, double *a1, double *p1, double *p1inf, int *nnd, int *nsim, double *epsplus, double *etaplus, double *aplus1, int *p, int *n, int *m, int *r, int *info,int *rankp, double *tol, int *nd, int *ndl, double *sim, double *c, int *simwhat, int *simdim, int *antithetics);
+void F77_NAME(simgaussianuncond)(int *timevar, double *zt, double *ht, double *tt, double *rtv, double *qt, double *a1, double *p1, double *p1inf, int *nnd, int *nsim, double *epsplus, double *etaplus, double *aplus1, int *p, int *n, int *m, int *r, int *info,int *rankp, double *tol, int *nd, int *ndl, double *sim, double *c, int *simwhat, int *simdim, int *antithetics);
 void F77_NAME(mvfilter)(int *tvz, double *zt, int *p, int *m, int *n, int *d, double *at, double *pt, double *pinf, double *vt, double *ft, double *finf);
