@@ -4,7 +4,7 @@ test_that("SSModel works properly",{
   d<-data.frame(x=rnorm(100))
   t12<-ts(cbind(t1=rnorm(100)+d$x,t2=rnorm(100)))
   t12[sample(size=50,1:200)]<-NA
-  expect_that(
+  expect_warning(
     model<-SSModel(t12~SSMcycle(period=10, type='common',Q=2)
                    +SSMcycle(period=10, type='distinct',P1=diag(c(1,1,2,2)),Q=diag(1:2))
                    +SSMtrend(2,type="common",Q=diag(c(1,0.5)))
@@ -16,12 +16,11 @@ test_that("SSModel works properly",{
                    +SSMseasonal(period=5,type="distinct",sea.type="trig",Q=diag(c(0.1,0.2)),
                                 P1=diag(rep(c(0.1,0.2),each=4)))
                    +SSMarima(ar=0.9,ma=0.2)+SSMregression(~-1+x,index=1,Q=1,data=d)
-    ),not(gives_warning()))
-  expect_that(print(model),not(gives_warning()))
-  expect_that(logLik(model),not(gives_warning()))
+    ), NA)
+  expect_warning(print(model), NA)
+  expect_warning(logLik(model), NA)
   expect_equal(logLik(model),-442.006705531500,tolerance=tol,check.attributes=FALSE)
-  expect_that(out<-KFS(model,filtering=c("state","mean"),smoothing=c("state","mean","disturbance")),
-              not(gives_warning()))
+  expect_warning(out<-KFS(model,filtering=c("state","mean"),smoothing=c("state","mean","disturbance")), NA)
   expect_equal(out$d,11)
   expect_equal(out$j,1)
 })
